==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-fa_IR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Persian (Iran) (http://www.transifex.com/tine20/tine20/language/fa_IR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fa_IR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "خط"

, "Caller Id"
: "شماره تماس گیرنده"

, "Start"
: "شروع"

, "Connected"
: "تماس برقرار شد"

, "Disconnected"
: "تماس قطع شد"

, "Duration"
: "مدت"

, "Ringing"
: "در حال زنگ خوردن"

, "Direction"
: "آدرس"

, "Source"
: "منبع"

, "Destination"
: "مقصد"

, "Phone"
: ""

, "Phones"
: "تلفن ها"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "شماره"

, "Cancel"
: "لغو کردن"

, "Dial"
: "تماس"

, "Error"
: "خطا"

, "Not possible to dial."
: "تماس ممکن نیست"

, "Edit phone settings"
: "ویرایش تنظیمات تلفن"

, "Dial number"
: "شماره تماس"

, "Initiate a new outgoing call"
: "آغاز تماس خروحی جدید"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "تماس با مخاطب"

, "Work"
: "محل کار"

, "Home"
: "منزل"

, "Cell"
: "موبایل"

, "Cell private"
: "موبایل شخصی"

, "Incoming call"
: "تماس ورودی"

, "Outgoing call"
: "تماس خروجی"

, "unknown number"
: "شماره ناشناس"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-fa_IR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Persian (Iran) (http://www.transifex.com/tine20/tine20/language/fa_IR/)\nLanguage: fa_IR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "تماس ورودی"

, "Outgoing call"
: "تماس خروجی"

, "unknown number"
: "شماره ناشناس"

, "Phone"
: ""

, "Line"
: "خط"

, "Number"
: "شماره"

, "Cancel"
: "لغو کردن"

, "Dial"
: "تماس"

, "Error"
: "خطا"

, "Not possible to dial."
: "تماس ممکن نیست"

, "Call contact"
: "تماس با مخاطب"

, "Work"
: "محل کار"

, "Home"
: "منزل"

, "Cell"
: "موبایل"

, "Cell private"
: "موبایل شخصی"

, "Edit phone settings"
: "ویرایش تنظیمات تلفن"

, "Dial number"
: "شماره تماس"

, "Initiate a new outgoing call"
: "آغاز تماس خروحی جدید"

, "Phones"
: "تلفن ها"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "شماره تماس گیرنده"

, "Start"
: "شروع"

, "Connected"
: "تماس برقرار شد"

, "Disconnected"
: "تماس قطع شد"

, "Duration"
: "مدت"

, "Ringing"
: "در حال زنگ خوردن"

, "Direction"
: "آدرس"

, "Source"
: "منبع"

, "Destination"
: "مقصد"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
